@@ -2,29 +2,35 @@
 
 ##' Write raster to PostGIS database table.
 ##'
-##' Sends R \code{Raster*} to a new PostGIS database table.
+##' Sends R raster to a new PostGIS database table.
 ##' 
 ##' RasterLayer names will be stored in an array in the column
 ##' "band_names", which will be restored in R when imported with the function
 ##' \code{\link[rpostgis]{pgGetRast}}.
+##' 
+##' Rasters from the \code{sp} package are converted to \code{raster}
+##' package objects prior to insert.
 ##'
 ##' @param conn A connection object to a PostgreSQL database
 ##' @param name A character string specifying a PostgreSQL schema (if
 ##'     necessary) and table name to hold the
 ##'     raster (e.g., \code{name = c("schema","table")})
-##' @param raster An R \code{RasterLayer}, \code{RasterBrick}, or \code{RasterStack}
+##' @param raster An R \code{RasterLayer}, \code{RasterBrick}, or \code{RasterStack} from 
+##'     raster package; a \code{SpatialGrid*} or \code{SpatialPixels*} from sp package
 ##' @param bit.depth The bit depth of the raster. Will be set to 32-bit
 ##'     (unsigned int, signed int, or float, depending on the data)
 ##'     if left null, but can be specified (as character) as one of the
 ##'     PostGIS pixel types (see \url{http://postgis.net/docs/RT_ST_BandPixelType.html})
-##' @param constraints Whether to create constraints from raster data. Recommened
+##' @param constraints Whether to create constraints from raster data. Recommended
 ##'     to leave \code{TRUE} unless applying constraints manually (see
 ##'     \url{http://postgis.net/docs/RT_AddRasterConstraints.html}).
 ##'     Note that constraint notices may print to the console,
-##'      depending on the PostgreSQL server settings.
+##'     depending on the PostgreSQL server settings.
 ##' @param overwrite Whether to overwrite the existing table (\code{name}).
-##' @author David Bucklin \email{dbucklin@@ufl.edu}
-##' @importFrom raster res blockSize extent t as.matrix values
+##' @author David Bucklin \email{david.bucklin@@gmail.com}
+##' @importFrom raster res blockSize extent t as.matrix values values<-
+##' @importFrom methods as
+##' @importFrom sp SpatialPixelsDataFrame
 ##' @export
 ##' @return TRUE for successful import.
 ##' 
@@ -35,8 +41,10 @@
 ##' pgWriteRast(conn, c("schema", "tablename"), raster_name)
 ##'
 ##' # basic test
-##' r<-raster(nrows=180, ncols=360, xmn=-180, xmx=180, ymn=-90, ymx=90, vals=1)
-##' pgWriteRast(conn, c("schema", "test"), raster = r, bit.depth = "2BUI", overwrite = TRUE)
+##' r <- raster::raster(nrows=180, ncols=360, xmn=-180, xmx=180,
+##'     ymn=-90, ymx=90, vals=1)
+##' pgWriteRast(conn, c("schema", "test"), raster = r,
+##'     bit.depth = "2BUI", overwrite = TRUE)
 ##' }
 
 pgWriteRast <- function(conn, name, raster, bit.depth = NULL, 
@@ -46,8 +54,25 @@ pgWriteRast <- function(conn, name, raster, bit.depth = NULL,
     if (!suppressMessages(pgPostGIS(conn))) {
         stop("PostGIS is not enabled on this database.")
     }
+  
+    r_class <- dbQuoteString(conn, class(raster)[1])
+  
+    # sp-handling
+    if (class(raster)[1] %in% c("SpatialPixelsDataFrame","SpatialGridDataFrame","SpatialGrid","SpatialPixels")) {
+      if (class(raster) %in% c("SpatialGrid", "SpatialPixels") || length(raster@data) < 2) {
+        # SpatialPixels needs a value
+        if (class(raster) == "SpatialPixels") raster <- SpatialPixelsDataFrame(raster, data = data.frame(rep(0, length(raster))))
+        raster <- as(raster, "RasterLayer")
+      } else {
+        raster <- as(raster, "RasterBrick")
+      }
+    }
     
+    # crs
+    r_crs <- dbQuoteString(conn, as.character(raster@crs))
+  
     nameq <- dbTableNameFix(conn, name)
+    namef <- dbTableNameFix(conn, name, as.identifier = FALSE)
     
     if (overwrite) {
         dbDrop(conn, name, ifexists = TRUE)
@@ -55,7 +80,7 @@ pgWriteRast <- function(conn, name, raster, bit.depth = NULL,
     
     # 1. create raster table
     tmp.query <- paste0("CREATE TABLE ", paste(nameq, collapse = "."), 
-        " (rid serial primary key, band_names text[], rast raster);")
+        " (rid serial primary key, band_names text[], r_class character varying, r_proj4 character varying, rast raster);")
     dbExecute(conn, tmp.query)
     
     r1 <- raster
@@ -92,29 +117,34 @@ pgWriteRast <- function(conn, name, raster, bit.depth = NULL,
       # rid counter
       n<-0
       
+      # handle empty data rasters by setting ndval to all values
+      if (all(is.na(values(rb)))) values(rb) <- ndval
+      
       # loop over blocks
       for (i in 1:tr$n) {
-          rr <- rb[tr$row[i]:(tr$row[i] + tr$nrows[i] - 1), , drop = FALSE]
+          suppressWarnings(rr <- rb[tr$row[i]:(tr$row[i] + tr$nrows[i] - 1), , drop = FALSE])
           
           for (l in 1:cr$n) {
-              r <- rr[, cr$row[l]:(cr$row[l] + cr$nrows[l] - 1), 
-                  drop = FALSE]
+              suppressWarnings(r <- rr[, cr$row[l]:(cr$row[l] + cr$nrows[l] - 1), 
+                  drop = FALSE])
               ex <- raster::extent(r)
               d <- dim(r)
-              
+
               # rid counter
               n <- n + 1
               
-              srid <- suppressMessages(pgSRID(conn, r@crs))
+              srid <- 0
+              try(srid <- suppressMessages(pgSRID(conn, r@crs, create.srid = TRUE)))
               
               # only ST_MakeEmptyRaster/ST_AddBand during first band loop
               if (b == 1) {
+                
                 # 2. make empty raster
                 tmp.query <- paste0("INSERT INTO ", paste(nameq, 
-                    collapse = "."), " (rid, band_names, rast) VALUES (",n, 
-                    ",",bnds,", ST_MakeEmptyRaster(", 
-                    d[2], ",", d[1], ",", ex[1], ",", ex[3], ",", 
-                    res[1], ",", res[2], ", 0, 0,", srid[1], ") );")
+                    collapse = "."), " (rid, band_names, r_class, r_proj4, rast) VALUES (",n, 
+                    ",",bnds,",",r_class,",",r_crs,", ST_MakeEmptyRaster(", 
+                    d[2], ",", d[1], ",", ex[1], ",", ex[4], ",", 
+                    res[1], ",", -res[2], ", 0, 0,", srid[1], ") );")
                 dbExecute(conn, tmp.query)
                 
                 # 3. new band
@@ -129,9 +159,9 @@ pgWriteRast <- function(conn, name, raster, bit.depth = NULL,
               
               mr <- raster::as.matrix(r)
               mr[is.na(mr)] <- ndval
-              r2 <- paste(rev(apply(mr, 1, FUN = function(x) {
+              r2 <- paste(apply(mr, 1, FUN = function(x) {
                   paste0("[", paste(x, collapse = ","), "]")
-              })), collapse = ",")
+              }), collapse = ",")
               
               tmp.query <- paste0("UPDATE ", paste(nameq, collapse = "."), 
                   " SET rast = ST_SetValues(rast,",b,", 1, 1, ARRAY[", 
@@ -152,10 +182,10 @@ pgWriteRast <- function(conn, name, raster, bit.depth = NULL,
     if (constraints) {
         # 5. add raster constraints
         tmp.query <- paste0("SELECT AddRasterConstraints(", dbQuoteString(conn, 
-            name[1]), "::name,", dbQuoteString(conn, name[2]), 
+            namef[1]), "::name,", dbQuoteString(conn, namef[2]), 
             "::name, 'rast'::name);")
         dbExecute(conn, tmp.query)
     }
     
     return(TRUE)
-}
\ No newline at end of file
+}
